@@ -275,7 +275,8 @@
 }
 
 /* created:  2002-07-18
- * modified: 2012-02-06 (test for path == nil)
+ * modified: 2016-03-14 (check for Extension folder Cenon_#.# in user library)
+ *           2012-02-06 (test for path == nil)
  *           2011-06-08 (add CAM.bundle to loadedFiles)
  *           2005-09-05 (load module only once)
  *
@@ -290,9 +291,16 @@
     int             i, j;
     NSFileManager   *fileManager = [NSFileManager defaultManager];
     NSMutableArray  *loadedFiles = [NSMutableArray array];
+    NSString        *version = [self version], *vMajor = nil;
+
+    if ( version )  // #.#.#
+    {   NSRange range = [version rangeOfString:@"." options:NSBackwardsSearch];
+        if (range.length)
+            vMajor = [version substringWithRange:NSMakeRange(0, [version length]-range.location+1)];    // "#.#"
+    }
 
     /* load modules */
-    for (i=0; i <= 5; i++)
+    for (i=0; i <= 6; i++)
     {   NSArray	*files;
 
         switch (i)
@@ -302,9 +310,14 @@
             case 0: path = [mainBundle resourcePath]; break;    // load modules from main bundle
             case 1: path = [userLibrary()  stringByAppendingPathComponent:@"Bundles"]; break;
             case 2: path = [localLibrary() stringByAppendingPathComponent:@"Bundles"]; break;
-            case 3: path = userBundlePath();   break;           // load modules from Home Library/Cenon of user
-            case 4: path = localBundlePath();  break;           // load modules from /Library/Extensions/Cenon
-            case 5: path = systemBundlePath(); break;           // load modules from /System/Library/Bundles/Cenon (GNUstep only)
+            case 3: if ( ! vMajor )
+                continue;
+                path = userBundlePath();                        // load modules from Home Library/Cenon_#.# of user
+                path = [path stringByAppendingFormat:@"_%@", vMajor];
+                break;
+            case 4: path = userBundlePath();   break;           // load modules from Home Library/Cenon of user
+            case 5: path = localBundlePath();  break;           // load modules from /Library/Extensions/Cenon
+            case 6: path = systemBundlePath(); break;           // load modules from /System/Library/Bundles/Cenon (GNUstep only)
         }
         if ( !path )
             continue;
@@ -476,7 +489,7 @@
     //NSString        *ext = [[fileName pathExtension] lowercaseString];
     DocView         *view = [[self currentDocument] documentView];
 
-    if ( [fileNameLC hasSuffix:@".cenon"] || [fileNameLC hasSuffix:@".cen"] )   // [ext isCaseInsensitiveLike:DOCUMENT_EXT]
+    if ( [fileNameLC hasSuffix:@".cenon"] || [fileNameLC hasSuffix:@".cen"] )
     {   NSString        *fileDirectory = fileName;
         NSDictionary	*plist = nil;
 
@@ -740,7 +753,7 @@
 - (BOOL)openFile:(NSString *)fileName
 {   id              list = nil;
     NSString        *path;
-    NSString        *ext = [fileName pathExtension];
+    NSString        *ext = [[fileName pathExtension] lowercaseString];
     NSFileManager   *fileManager = [NSFileManager defaultManager];
 
     if (!appIsRunning)	// give application a chance to load modules first
@@ -752,7 +765,7 @@
     document = nil;
     if ( ![fileManager fileExistsAtPath:fileName] )
         return NO;
-    if ( [ext isCaseInsensitiveLike:DOCUMENT_EXT] || [ext isCaseInsensitiveLike:@"cen"] )
+    if ( [ext isEqual:DOCUMENT_EXT] || [ext isEqual:@"cen"] )
     {	int	i;
 
         for (i=[[self windows] count]-1; i>=0; i--)
@@ -773,7 +786,7 @@
     else if ( (list = [self listFromFile:fileName]) )
     {
         /* Fonts: special treatment for fonts */
-        if ( [ext isCaseInsensitiveLike:@".font"] || [ext isCaseInsensitiveLike:@".pfa"] || [ext isCaseInsensitiveLike:@".pfb"] )
+        if ( [ext isEqual:@".font"] || [ext isEqual:@".pfa"] || [ext isEqual:@".pfb"] )
         {
             document = [Document new];
             [self setCurrentDocument:nil];
