@@ -1256,9 +1256,9 @@ static NSMutableArray *zoneList = nil;
 
     if ([savepanel runModalForDirectory:directory file:[name stringByDeletingPathExtension]])
     {   NSString    *path = [savepanel filename];
-        NSString    *ext = [path pathExtension];
+        NSString    *ext  = [[path pathExtension] lowercaseString];
 
-        if ( [ext isCaseInsensitiveLike:DOCUMENT_EXT] || [ext isCaseInsensitiveLike:@"cen"] )
+        if ( [ext isEqual:DOCUMENT_EXT] || [ext isEqual:@"cen"] )
         {   [self setName:path];
             return [self save];
         }
@@ -1266,17 +1266,17 @@ static NSMutableArray *zoneList = nil;
         {   NSRunAlertPanel(SAVE_TITLE, EXPORTLOCK_STRING, nil, nil, nil);
             return NO;
         }
-        if (      [ext isCaseInsensitiveLike:EPS_EXT]     || [ext isCaseInsensitiveLike:@"ps"] )
+        if (      [ext isEqual:EPS_EXT]     || [ext isEqual:@"ps"] )
             [self saveEPS:path];
-        else if ( [ext isCaseInsensitiveLike:GERBER_EXT]  || [ext isCaseInsensitiveLike:@"ger"] )
+        else if ( [ext isEqual:GERBER_EXT]  || [ext isEqual:@"ger"] )
             [self saveGerber:path];
-        else if ( [ext isCaseInsensitiveLike:HPGL_EXT]    || [ext isCaseInsensitiveLike:@"hgl"] || [ext isCaseInsensitiveLike:@"plt"] )
+        else if ( [ext isEqual:HPGL_EXT]    || [ext isEqual:@"hgl"] || [ext isEqual:@"plt"] )
             [self saveHPGL:path];
-        else if ( [ext isCaseInsensitiveLike:DXF_EXT])
+        else if ( [ext isEqual:DXF_EXT])
             [self saveDXF:path];
-        else if ( [ext isCaseInsensitiveLike:FONT_EXT])
+        else if ( [ext isEqual:FONT_EXT])
             [self saveFont:path];
-        else if ( [ext isCaseInsensitiveLike:TIFF_EXT]    || [ext isCaseInsensitiveLike:@"tif"] )
+        else if ( [ext isEqual:TIFF_EXT]    || [ext isEqual:@"tif"] )
             [self saveTiff:path];
     }
 
@@ -1353,7 +1353,7 @@ static NSMutableArray *zoneList = nil;
 }
 
 /* created:  2010-06-29
-   modified: 2010-11-26
+   modified: 2017-04-12 (handler for -setDepthLimit:, which fails on Mac OS 10.12)
  */
 - (BOOL)saveTiff:(NSString*)filename
 {   NSArray             *layerList = [[self documentView] layerList];
@@ -1386,7 +1386,13 @@ static NSMutableArray *zoneList = nil;
      * in which we draw the scaled black copy of original path on white background NSBackingStoreBuffered NSBackingStoreRetained
      */
     win = [[NSWindow alloc] initWithContentRect:conRect styleMask:NSBorderlessWindowMask backing:NSBackingStoreRetained defer:NO];
-    [win setDepthLimit:NSBestDepth(NSCalibratedWhiteColorSpace, 8, 8, YES, NULL)];
+#if !defined(__APPLE__) // GNUStep, OpenStep 4.2
+    NS_DURING   // FIXME: this raises an exception on Mac oS 10.12 ("unsupported backing store depth" (264)), nor does it work on Apple
+    [win setDepthLimit:NSBestDepth(NSCalibratedWhiteColorSpace, 8, 8, YES, NULL)];  // 264 (unsupported on Mac OS 10.12)
+    NS_HANDLER
+    NSLog(@"Exception in [NSSWindow -setDepthLimit:]: %@", [localException reason]);
+    NS_ENDHANDLER
+#endif
 
     [win setBackgroundColor:[NSColor whiteColor]];
 #if DEBUG_TIFFEXPORT
