@@ -1,12 +1,13 @@
 /* VGraphic.m
  * Graphic object - root class
  *
- * Copyright (C) 1996-2015 by Cenon GmbH
+ * Copyright (C) 1996-2016 by Cenon GmbH
  * Author:   Georg Fleischmann
  * WWW:      http://www.cenon.info
  *
  * created:  1996-01-29
- * modified: 2013-01-15 (-coordCenter added)
+ * modified: 2016-05-24 (-objectsOfClass:inArray: add objects from inside groups = recursive)
+ *           2013-01-15 (-coordCenter added)
  *           2011-05-28 (excluded, -isExcluded, -setExcluded:, +initialize: version=5)
  *           2011-04-06 (-drawStartAtScale: added)
  *           2011-03-04 (-size, -setSize: default implementation to make it work for all objects)
@@ -222,14 +223,28 @@ static void drawControl( NSPoint origin, BOOL direct, BOOL selectedKnob, float s
     return nil;
 }
 
+/* modified: 2016-08-18 (recursive)
+ */
 + (NSArray*)objectsOfClass:(Class)cls inArray:(NSArray*)array
 {   int             i;
     NSMutableArray  *mArray = nil;
 
     for ( i=[array count]-1; i>=0; i-- )
-    {   VGraphic	*g = [array objectAtIndex:i];
+    {   VGraphic    *g = [array objectAtIndex:i];
 
-        if ( [g isMemberOfClass:cls] )
+        if ( [g isMemberOfClass:[VGroup class]] )
+        {   NSArray *aArray = [VGraphic objectsOfClass:cls inArray:[(VGroup*)g list]];
+            int     j;
+
+            for ( j=[aArray count]-1; j>=0; j-- )
+            {   VGraphic	*g = [aArray objectAtIndex:j];
+
+                if ( !mArray )
+                    mArray = [NSMutableArray array];
+                [mArray addObject:g];
+            }
+        }
+        else if ( [g isMemberOfClass:cls] )
         {
             if ( !mArray )
                 mArray = [NSMutableArray array];
