@@ -1,7 +1,7 @@
 /* InspectorPanel.m
  * Cenon Inspector panel
  *
- * Copyright (C) 1996-2011 by vhf interservice GmbH
+ * Copyright (C) 1996-2014 by Cenon GmbH
  * Author:   Georg Fleischmann
  *
  * created:  1993-10-01
@@ -10,22 +10,22 @@
  *           2008-03-17 (Accessory replaces AllText)
  *
  * This program is free software; you can redistribute it and/or
- * modify it under the terms of the vhf Public License as
- * published by vhf interservice GmbH. Among other things, the
+ * modify it under the terms of the Cenon Public License as
+ * published by Cenon GmbH. Among other things, the
  * License requires that the copyright notices and this notice
  * be preserved on all copies.
  *
  * This program is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
- * See the vhf Public License for more details.
+ * See the Cenon Public License for more details.
  *
- * You should have received a copy of the vhf Public License along
- * with this program; see the file LICENSE. If not, write to vhf.
+ * You should have received a copy of the Cenon Public License along
+ * with this program; see the file LICENSE. If not, write to Cenon.
  *
- * vhf interservice GmbH, Im Marxle 3, 72119 Altingen, Germany
- * eMail: info@vhf.de
- * http://www.vhf.de
+ * Cenon GmbH, Schwabstr. 45, 72108 Rottenburg a.N., Germany
+ * eMail: info@Cenon.com
+ * http://www.Cenon.de
  */
 
 #include <AppKit/AppKit.h>
@@ -96,7 +96,10 @@
     [self loadGraphic:(obj) ? obj : nil];
 }
 
-- (void)loadGraphic:(id)g
+/*
+ * modified: 2014-07-06 id => VGraphic*
+ */
+- (void)loadGraphic:(VGraphic*)g
 {   id          newWindow;
     NSString    *string = @"ipCrosshairs.tiff";
 
@@ -194,8 +197,9 @@
         string = @"ipText.tiff";
     }
     else if ([g isKindOfClass:[VTextPath class]])
-    {   id	tpGraphic = [g path];
-        id	tpView, tpWindow = nil;
+    {   VPath           *tpGraphic = [(VTextPath*)g path];
+        NSClipView      *tpView;
+        IPBasicLevel    *tpWindow = nil;
 
         if (!textPathWindow)
         {
@@ -377,11 +381,13 @@
             activeWindow = objectWindow;
             break;
         case IP_STROKEWIDTH:	// stroke width
+            [[NSColorPanel sharedColorPanel] setShowsAlpha:YES];
             [self windowAt:IP_STROKEWIDTH];
             [self setLevelView:[allStrokeWindow contentView]];
             activeWindow = allStrokeWindow;
             break;
         case IP_FILLING:	// filling
+            [[NSColorPanel sharedColorPanel] setShowsAlpha:YES];
             [self windowAt:IP_FILLING];
             [self setLevelView:[allFillingWindow contentView]];
             activeWindow = allFillingWindow;
@@ -474,7 +480,7 @@
     }
 }
 
-- (void)setLevelView:theView
+- (void)setLevelView:(NSView*)theView
 {
     if ( ! defaultView )
         defaultView = [[levView contentView] retain];
