@@ -2,7 +2,7 @@
 # update project from archive
 
 PROJECT=~/Projects/Libraries/VHFShared		# project directory (the directory we have to copy)
-ARCHIVE=/mnt/vhfInterservice/Projects/Libraries/VHFShared	# archive directory
+ARCHIVE=/Network/vhfInterservice/Projects/Libraries/VHFShared	# archive directory
 
 echo Copy files from $ARCHIVE to $PROJECT
 
@@ -23,14 +23,14 @@ do
     fn=`echo $fn | sed -e 's|./||'`
 
     # tiff files
-    #if [ `echo $fn | grep -c '.tiff'` != '0' -a `echo $fn | grep -c '/'` == '0' ]; then
-    #  if ! cmp -s $fn $PROJECT/Icons/$fn ; then
-    #    echo Icons/$fn
-    #    cp $fn $PROJECT/Icons/$fn
-    #  fi
+    if [ `echo $fn | grep -c '.tiff'` != '0' -a `echo $fn | grep -c '/'` == '0' ]; then
+      if ! cmp -s $fn $PROJECT/Icons/$fn ; then
+        echo Icons/$fn
+        cp $fn $PROJECT/Icons/$fn
+      fi
 
     # log files -> ChangeLog/
-    if [ `echo $fn | grep -c '....-...txt'` != '0' -a `echo $fn | grep -c 'ChangeLog'` = '0' ]; then
+    else if [ `echo $fn | grep -c '....-...txt'` != '0' -a `echo $fn | grep -c 'ChangeLog'` = '0' ]; then
       if ! cmp -s $fn $PROJECT/ChangeLog/$fn ; then
         echo ChangeLog/$fn
         cp $fn $PROJECT/ChangeLog/$fn
@@ -48,6 +48,14 @@ do
         cp $fn $PROJECT/$fn
       fi
 
-    fi
+    fi fi
   fi fi
 done
+
+
+# update Cenon
+PROJECTS=~/Projects
+SHARED=$PROJECTS/Libraries/VHFShared
+
+cd $PROJECTS/Cenon/Source/Cenon
+cp -R $SHARED .
