@@ -1,14 +1,15 @@
 /*
  * vhfCommonFunctions.m
  *
- * Copyright (C) 1996-2014 by Cenon GmbH
+ * Copyright (C) 1996-2018 by Cenon GmbH
  * Author:   Georg Fleischmann
  *
  * created:  1996-01-25
- * modified: 2012-02-28 (vhfMOdulo() added)
+ * modified: 2015-03-13 (NSDecimalSeparator only for OpenStep 4.2)
+ *           2012-02-28 (vhfMOdulo() added)
  *           2012-02-06 (vhfUserDocuments())
  *
- * This file is part of the vhf Shared Library.
+ * This file is part of the Cenon Shared Library.
  *
  * This library is free software; you can redistribute it and/or
  * modify it under the terms of the Cenon Public License as
@@ -41,6 +42,42 @@
 #include "VHFStringAdditions.h"
 //#include "VHFScannerAdditions.h"
 
+#if 0   // standard C
+NSString *cenRunCommand(NSString *cmd)
+{   NSString    *output = nil;
+    FILE        *read_fp;
+    char        buffer[BUFSIZ + 1];
+    int         chars_read;
+
+    memset(buffer, '\0', sizeof(buffer));
+    read_fp = popen(cmd.UTF8String, "r");
+    if (read_fp != NULL)
+    {   chars_read = fread(buffer, sizeof(char), BUFSIZ, read_fp);
+        if (chars_read > 0)
+            output = [NSString stringWithUTF8String:buffer];
+        pclose(read_fp);
+    }
+    return output;
+}
+#else   // NSTask
+NSString *cenRunCommand(NSString *cmd)
+{   NSPipe          *pipe = [NSPipe pipe];
+    NSFileHandle    *file = [pipe fileHandleForReading];
+    NSTask          *task = [[NSTask alloc] init];
+    NSString        *output;
+
+    [task setLaunchPath: @"/bin/sh"];
+    //[task setArguments:@[@"-c", [NSString stringWithFormat:@"%@", cmd]]];
+    [task setArguments:[NSArray arrayWithObjects:@"-c", [NSString stringWithFormat:@"%@", cmd], nil]];
+    [task setStandardOutput:pipe];
+    [task launch];
+    output = [[NSString alloc] initWithData:[file readDataToEndOfFile] encoding:NSUTF8StringEncoding];
+    [file closeFile];
+    [task release];
+    return [output autorelease];
+}
+#endif
+
 /* sort popup entries
  *
  * created:  03.05.93
@@ -357,8 +394,10 @@ NSString *buildDecimalString(float value, VHFLimits limits, int digits)
     }
 
     /* workaround for OpenStep */
+#if !defined(GNUSTEP_BASE_VERSION) && !defined(__APPLE__)	// OpenStep 4.2
     if ( [NSDecimalSeparator isEqual:@","] )
         return [string stringByReplacing:@"." by:@","];
+#endif
 
     return string;
 }
@@ -404,8 +443,10 @@ NSString *buildRoundedString(float value, float limitL, float limitH)
     }
 
     /* workaround for OpenStep */
+#if !defined(GNUSTEP_BASE_VERSION) && !defined(__APPLE__)	// OpenStep 4.2
     if ( [NSDecimalSeparator isEqual:@","] )
         return [string stringByReplacing:@"." by:@","];
+#endif
 
     return string;
 }
@@ -434,8 +475,10 @@ NSString *vhfStringWithFloat(float value)
     }
 
     /* workaround for OpenStep */
+#if !defined(GNUSTEP_BASE_VERSION) && !defined(__APPLE__)	// OpenStep 4.2
     if ( [NSDecimalSeparator isEqual:@","] )
         return [string stringByReplacing:@"." by:@","];
+#endif
 
     return string;
 }
@@ -466,8 +509,10 @@ NSString *vhfStringWithDouble(double value)
     }
 
     /* workaround for OpenStep */
+#if !defined(GNUSTEP_BASE_VERSION) && !defined(__APPLE__)	// OpenStep 4.2
     if ( [NSDecimalSeparator isEqual:@","] )
         return [string stringByReplacing:@"." by:@","];
+#endif
 
     return string;
 }
@@ -480,10 +525,16 @@ double vhfModulo(double v, double denom)
     return (v - floor(v / denom) * denom);
 }
 
-/* created:   16.07.93
- * modified:  16.07.93
- * purpose:   compare function for qsort
- * parameter: value1, value2 
+/* created:   1993-07-16
+ * modified:  2015-12-29
+ *
+ * purpose:   sort values in 'array' upwards
+ * parameter: array
+ *            cnt (number of values)
+ * return:    none
+ *
+ * compare function for qsort:
+ * parameter: value1, value2
  * return:    value1 < value2 -> -1
  *            value1 > value2 -> 1
  *            value1 = value2 -> 0
@@ -496,20 +547,27 @@ static int compareDouble(const void *value1, const void *value2)
         return(1);
     return(0);
 }
-
-/* created:   16.07.93
- * modified:  16.07.93 28.02.97
- *
- * purpose:   sort values in 'array' upwards
- * parameter: array
- *            cnt (number of values)
- * return:    none
- */
-void sortValues(double *array, int cnt)
+void sortValues(double *array, int cnt) { cenSortDoubleValues(array, cnt); }  // DEPRECATED
+void cenSortDoubleValues(double *array, int cnt)
 {
     qsort(array, cnt, sizeof(double), compareDouble);
 }
 
+/* created: 2015-12-29
+ */
+static int compareInt(const void *value1, const void *value2)
+{
+    if (*(int*)value1 < *(int*)value2)
+        return(-1);
+    if (*(int*)value1 > *(int*)value2)
+        return(1);
+    return(0);
+}
+void cenSortIntValues(int *array, int cnt)
+{
+    qsort(array, cnt, sizeof(int), compareInt);
+}
+
 #if 0
 /* count number of apearances of a character in a string
  */
