@@ -1,10 +1,11 @@
 /* ChangeDetail.m
  *
- * Copyright (C) 1993-2014 by Cenon GmbH
+ * Copyright (C) 1993-2015 by Cenon GmbH
  * Authors:  Georg Fleischmann
  *
  * created:  1993 based on the Draw example files
- * modified: 2011-05-28 (ExcludeChangeDetail added)
+ * modified: 2015-11-25 (FillChangeDetail: -personalChangeExpected: selector(setFilled:))
+ *           2011-05-28 (ExcludeChangeDetail added)
  *
  * The ChangeDetail.h and ChangeDetail.m files contain
  * the @interfaces and @implementations for the 11 
@@ -16,6 +17,7 @@
  * ChangeDetail
  *     ArrowChangeDetail
  *     DimensionsChangeDetail
+ *     ExcludeChangeDetail
  *     FillColorChangeDetail
  *     FillModeChangeDetail
  *     LineCapChangeDetail
@@ -65,25 +67,25 @@
     if ([graphic isKindOfClass:[VGroup class]] && [self useNestedDetails])
     {
         detailsDetails = [[NSMutableArray alloc] init];
-	subGraphics = [(VGroup *)graphic list];
-	count = [subGraphics count];
-	changeExpected = NO;
-	for (i = 0; i < count; i++)
-	{   changeDetail = [[[aChange changeDetailClass] alloc] initGraphic:[subGraphics objectAtIndex:i] change:aChange]; // here the changeExpected of the changeDetail will set !
+        subGraphics = [(VGroup *)graphic list];
+        count = [subGraphics count];
+        changeExpected = NO;
+        for (i = 0; i < count; i++)
+        {   changeDetail = [[[aChange changeDetailClass] alloc] initGraphic:[subGraphics objectAtIndex:i] change:aChange]; // here the changeExpected of the changeDetail will set !
 
             if (![changeDetail changeExpected]) // check if changeExpected from changeDetail !
             {   [changeDetail release]; // no changeDetail for this object (line but radialCenter Change)
                 continue;
             }
-	    changeExpected = YES; // changeExpected || [changeDetail changeExpected];
-	    [detailsDetails addObject:changeDetail];
+            changeExpected = YES; // changeExpected || [changeDetail changeExpected];
+            [detailsDetails addObject:changeDetail];
             [changeDetail release];
-	}
+        }
     }
     else
     {
         detailsDetails = nil;
-	changeExpected = [self personalChangeExpected];
+        changeExpected = [self personalChangeExpected];
     }
     return self;
 }
@@ -267,7 +269,7 @@
 }
 - (BOOL)personalChangeExpected
 {
-    if (![graphic respondsToSelector:@selector(setFilled)])
+    if (![graphic respondsToSelector:@selector(setFilled:)])
         return NO;
     return ([graphic filled] != [(FillGraphicsChange*)change fill]);
 }
@@ -281,7 +283,7 @@
     {
         default: oldColor = [[graphic color] copy]; break;
         case 1:  oldColor = [[(VPolyLine*)graphic fillColor] copy]; break;
-        case 2:  oldColor = [[(VPolyLine*)graphic endColor] copy];
+        case 2:  oldColor = [[(VPolyLine*)graphic endColor]  copy];
     }
 }
 - (void)undoIt
@@ -376,7 +378,7 @@
 }
 - (BOOL)personalChangeExpected
 {
-    if (![graphic respondsToSelector:@selector(setLength)])
+    if (![graphic respondsToSelector:@selector(setLength:)])
         return NO;
     return ([graphic length] != [(LengthGraphicsChange*)change length]);
 }
@@ -454,12 +456,12 @@
 {   float	distance = MAXCOORD;
 
     newPoint = [change point];
-    if ([graphic isKindOfClass:[VPath class]])	// notice the hole old graphic+index (we cant recreate)
+    if ([graphic isKindOfClass:[VPath class]])          // notice the hole old graphic+index (we cant recreate)
     {
         newPoint = [(VPath*)graphic nearestPointOnObject:&oldIx distance:&distance toPoint:newPoint];
         oldGraphic = [[[(VPath*)graphic list] objectAtIndex:oldIx] copy];
     }
-    else // VPolyLine
+    else if ([graphic isKindOfClass:[VPolyLine class]]) // VPolyLine
     {   newPoint = [(VPolyLine*)graphic nearestPointInPtlist:&pt_num distance:&distance toPoint:newPoint];
         pt_num += 1; // pt_num is from point befor newPoint !
     }
@@ -479,7 +481,7 @@
             [[(VPath*)graphic list] insertObject:oldGraphic atIndex:oldIx];
             /* update path bounds ! hier nicht ganz so wichtig */
     }
-    else // VPolyLine
+    else if ([graphic isKindOfClass:[VPolyLine class]]) // VPolyLine
     {
         [(VPolyLine*)graphic removePointWithNum:pt_num];
     }
@@ -487,7 +489,8 @@
 - (void)redoIt
 {
     /* VPolyLine and Vpath the same */
-    [(VPolyLine*)graphic addPointAt:newPoint];   
+    if ([graphic isKindOfClass:[VPath class]] || [graphic isKindOfClass:[VPolyLine class]]) // VPath or VPolyLine
+    [(VPolyLine*)graphic addPointAt:newPoint];
 }
 @end
 
